@@ -707,6 +707,7 @@ testMiscUnions (test_TestFactory   factory,
 	test_UnionServer   obj;
 	test_EnumUnion     retn;
 	test_unionSeq      inSeq;
+	test_VariableLengthUnion inSeq_buffer[3];
 	test_BooleanUnion  inArg;
 	test_ArrayUnion   *outArg;
 	int                i;
@@ -716,17 +717,17 @@ testMiscUnions (test_TestFactory   factory,
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
 	inSeq._length  = inSeq._maximum = 3;
-	inSeq._buffer  = test_unionSeq_allocbuf (3);
-	inSeq._release = CORBA_TRUE;
+	inSeq._buffer  = inSeq_buffer;
+	inSeq._release = CORBA_FALSE;
 	inSeq._buffer [0]._d   = 4;
 	inSeq._buffer [0]._u.z = CORBA_TRUE;
 	inSeq._buffer [1]._d   = 2;
-	inSeq._buffer [1]._u.y = CORBA_string_dup ("blah");
+	inSeq._buffer [1]._u.y = "blah";
 	inSeq._buffer [2]._d   = 55;
 	inSeq._buffer [2]._u.w = constants_LONG_IN;
 
 	inArg._d   = 1;
-	inArg._u.y = CORBA_string_dup ("blah de blah");
+	inArg._u.y = "blah de blah";
 
 	retn = test_UnionServer_opMisc (obj, &inSeq, &inArg, &outArg, ev);
 
@@ -771,22 +772,22 @@ testFixedLengthArray (test_TestFactory   factory,
   objref = test_TestFactory_getArrayServer (factory, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inArg[i] = constants_SEQ_LONG_IN[i];
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inoutArg[i] = constants_SEQ_LONG_INOUT_IN[i];
 
   retn = test_ArrayServer_opLongArray (objref, inArg, inoutArg, outArg, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (inArg[i]==constants_SEQ_LONG_IN[i]);
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (inoutArg[i]==constants_SEQ_LONG_INOUT_OUT[i]);
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (outArg[i]==constants_SEQ_LONG_OUT[i]);
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (retn[i]==constants_SEQ_LONG_RETN[i]);
 
   CORBA_free (retn);
@@ -808,19 +809,19 @@ testVariableLengthArray (test_TestFactory   factory,
   objref = test_TestFactory_getArrayServer (factory, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inArg[i] = CORBA_string_dup (constants_SEQ_STRING_IN[i]);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inoutArg[i] = CORBA_string_dup (constants_SEQ_STRING_INOUT_IN[i]);
 
   retn = test_ArrayServer_opStrArray (objref, inArg, inoutArg, &outArg, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	CORBA_free (inArg[i]); 
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
         CORBA_free (inoutArg[i]);
 
   CORBA_free (outArg);
@@ -1251,7 +1252,7 @@ testMisc (test_TestFactory   factory,
 		g_assert (!strcmp (ev->_id, "IDL:CORBA/BAD_OPERATION:1.0"));
 		CORBA_exception_free (ev);
 	}
-	
+
 	g_assert (ORBit_copy_value (NULL, TC_CORBA_boolean) == NULL);
 
 	objref = test_TestFactory_getBasicServer (factory, ev);
@@ -1260,6 +1261,22 @@ testMisc (test_TestFactory   factory,
 	g_assert (CORBA_Object_is_a (objref, "IDL:orbit/test/BasicServer:1.0", ev));
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
+	{ /* IOR stringification */
+		CORBA_char *ior;
+		CORBA_Object o2;
+
+		ior = CORBA_ORB_object_to_string (global_orb, factory, ev);
+		g_assert (ev->_major == CORBA_NO_EXCEPTION);
+
+		o2 = CORBA_ORB_string_to_object (global_orb, ior, ev);
+		g_assert (ev->_major == CORBA_NO_EXCEPTION);
+		
+		CORBA_free (ior);
+
+		g_assert (o2 == factory);
+		CORBA_Object_release (o2, ev);
+	}
+	
 	test_BasicServer_noImplement (objref, ev);
 	g_assert (ev->_major == CORBA_SYSTEM_EXCEPTION);
 	g_assert (!strcmp (ev->_id, "IDL:CORBA/NO_IMPLEMENT:1.0"));
